# COPR Ligenix's spec file for glpi-plugin-protocolsmanager
#
# Copyright (c) 2021-2023 Jean-Marc Liger
#
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global pluginname protocolsmanager
%global glpi_min   9.5
%global glpi_max   9.6

Name:           glpi-plugin-%{pluginname}
Version:        1.4.2
Release:        3%{?dist}
Summary:        Plugin to make PDF reports with user inventory

License:        GPLv3
URL:            https://github.com/mateusznitka/%{pluginname}

Source0:        https://github.com/mateusznitka/%{pluginname}/releases/download/%{version}/%{pluginname}.tar.gz

BuildArch:      noarch

%if 0%{?fedora} || 0%{?rhel} >= 8
Requires:      (glpi >= %{glpi_min} with glpi < %{glpi_max})
%else
Requires:       glpi >= %{glpi_min}
Requires:       glpi <  %{glpi_max}
%endif

Provides:       bundled(php-dompdf)

%description
Plugin to make PDF reports with user inventory

Features:
- Making PDFs with all or selected user inventory
- Saving protocols in GLPI Documents
- Possibility to create different protocol templates
- Templates have configurable name, font, orientation, logo image, city, content and footer
- Possibility to make comments to any selected item
- Showing Manufacturer (only first word to be clearly) and Model of item
- Showing serial number or inventory number in one or two columns
- Possibility to add custom rows
- Possibility to add notes to export


%prep
%setup -q -c

# remove unused files
find %{pluginname} -name .git* -delete -print
find %{pluginname} -name \*.xml* -delete -print
find %{pluginname} -name \*.yml* -delete -print
find %{pluginname} -name composer.json -delete -print

# dos2unix to avoid rpmlint warnings
find %{pluginname} -type d -exec chmod 0755 '{}' +
find %{pluginname} -type f -exec chmod 0644 '{}' +
for f in $(find %{pluginname} -type f -exec file '{}' + | grep CRLF | cut -d":" -f1); do
   sed -i 's/\r//' $f
done

# move doc files
mkdir docs 
mv %{pluginname}/docs/        docs/
mv %{pluginname}/README.md    docs/
mv %{pluginname}/pdf_ico.png  docs/
mv %{pluginname}/screenshots/ docs/


%build
# empty build


%install
mkdir -p %{buildroot}%{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}

mkdir -p %{buildroot}/%{_datadir}/glpi/plugins
cp -ar %{pluginname} %{buildroot}/%{_datadir}/glpi/plugins/%{pluginname}


%files
%doc docs/*
%dir %{_datadir}/glpi/plugins/%{pluginname}
%{_datadir}/glpi/plugins/%{pluginname}/*.php
%{_datadir}/glpi/plugins/%{pluginname}/css
%{_datadir}/glpi/plugins/%{pluginname}/dompdf
%{_datadir}/glpi/plugins/%{pluginname}/front
%{_datadir}/glpi/plugins/%{pluginname}/img
%{_datadir}/glpi/plugins/%{pluginname}/inc
# Data
%attr(750,apache,root) %{_localstatedir}/lib/glpi/files/_plugins/%{pluginname}


%changelog
* Wed May 03 2023 Jean-Marc Liger <ligenix@iscp.fr> - 1.4.2-3
- Move screenshots to docs

* Fri May 21 2021 Jean-Marc Liger <ligenix@iscp.fr> - 1.4.2-2
- dos2unix

* Mon May 17 2021 Jean-Marc Liger <ligenix@iscp.fr> - 1.4.2-1
- Initial RPM based on Remi Collet previous GLPI plugins spec files
